
#ifndef _C11_kl521_
#define _C11_kl521_

#ifdef __cplusplus
extern "C" {
#endif

static EIF_REFERENCE F1197_10868_body(EIF_REFERENCE);
extern EIF_REFERENCE F1197_10868(EIF_REFERENCE);
extern void EIF_Minit521(void);

#ifdef __cplusplus
}
#endif

#endif
